@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -23,19 +23,23 @@
  * (with wrap around).
  */
 
-#include <qobjectlist.h>
+#include "multiview.h"
+
+#include <QObject>
+
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kconfiggroup.h>
 
-#include "multiview.h"
 #include "tabview.h"
 
+
 //
 // MultiView
 //
 
-MultiView::MultiView(TopLevel* top, QWidget* parent, const char* name)
-    : QSplitter(parent, name), TraceItemView(0, top)
+MultiView::MultiView(TopLevel* top, QWidget* parent)
+    : QSplitter(parent), TraceItemView(0, top)
 {
   // default
   setOrientation(Qt::Horizontal);
@@ -66,17 +70,17 @@ void MultiView::appendView()
 
     TabView* tv = new TabView(this, this,
 			      QString("TabView-%1").arg(n).ascii());
-    connect(tv, SIGNAL(activated(TabView*)),
+    connect(tv, SIGNAL(tabActivated(TabView*)),
 	    this, SLOT(tabActivated(TabView*)) );
     _views.append(tv);
     tv->show();
 
     // set same attributes as in active view
-    tv->set(0, _data, _costType, _costType2,
+    tv->set(0, _data, _eventType, _eventType2,
 	    _groupType, _partList, _activeItem, 0);
     tv->updateView();
 
-    if (0) kdDebug() << "MultiView::appendView, now "
+    if (0) kDebug() << "MultiView::appendView, now "
 		     << _views.count() << endl;
 }
 
@@ -96,7 +100,7 @@ void MultiView::removeView()
     _views.removeRef(last);
     delete last;
 
-    if (0) kdDebug() << "MultiView::removeView, now "
+    if (0) kDebug() << "MultiView::removeView, now "
 		     << _views.count() << endl;
 }
 
@@ -105,7 +109,7 @@ void MultiView::tabActivated(TabView* newActiveTab)
 {
     if (_active == newActiveTab) return;
 
-    if (0) kdDebug() << "MultiView::tabActivated " 
+    if (0) kDebug() << "MultiView::tabActivated "
 		     << newActiveTab->name() << endl;
 
     TraceItem* oldActiveItem = 0;
@@ -122,7 +126,7 @@ void MultiView::tabActivated(TabView* newActiveTab)
 
 void MultiView::selected(TraceItemView* sender, TraceItem* i)
 {
-    if (0) kdDebug() << "MultiView::selected " << i->name()
+    if (0) kDebug() << "MultiView::selected " << i->name()
 		     << ", sender " << sender->widget()->name() << endl;
 
      // we react only on selection changes of the active TabView
@@ -132,7 +136,7 @@ void MultiView::selected(TraceItemView* sender, TraceItem* i)
     TabView* next = _views.next();
     if (!next) next = _views.first();
 
-    // don't change item of active tab
+    // do not change item of active tab
     if (next == _active) return;
 
     next->activate(i);
@@ -141,7 +145,7 @@ void MultiView::selected(TraceItemView* sender, TraceItem* i)
 
 void MultiView::activated(TraceItemView* sender, TraceItem* i)
 {
-    if (0) kdDebug() << "MultiView::activated " << i->name()
+    if (0) kDebug() << "MultiView::activated " << i->name()
 		     << ", sender " << sender->widget()->name() << endl;
 
     // we react only on selection changes of the active TabView
@@ -154,7 +158,7 @@ void MultiView::doUpdate(int changeType)
 {
     TabView* tv;
     for(tv=_views.first(); tv; tv=_views.next()) {
-	tv->set(changeType, _data, _costType, _costType2,
+	tv->set(changeType, _data, _eventType, _eventType2,
 		_groupType, _partList,
 		(tv == _active) ? _activeItem : tv->activeItem(),
 		tv->selectedItem());
@@ -166,23 +170,23 @@ void MultiView::doUpdate(int changeType)
 
 
 void MultiView::readViewConfig(KConfig* c,
-			       QString prefix, QString postfix,
-			       bool withOptions)
+                               const QString& prefix, const QString& postfix,
+                               bool withOptions)
 {
   if (0) qDebug("%s::readConfig(%s%s)", name(),
 		prefix.ascii(), postfix.ascii());
 
   QString active;
-  KConfigGroup* g = configGroup(c, prefix, postfix);
-  int n = g->readNumEntry("Panels", 1);
+  KConfigGroup g = configGroup(c, prefix, postfix);
+  int n = g.readEntry("Panels", 1);
   setChildCount(n);
-  setOrientation( (g->readEntry("Orientation") == QString("Horizontal")) ?
+  setOrientation( (g.readEntry("Orientation") == QString("Horizontal")) ?
 		  Qt::Horizontal : Qt::Vertical );
-  
-  setSizes(g->readIntListEntry("PanelSizes"));
-  
-  active = g->readEntry("ActivePanel", "");
-  delete g;
+
+  if ( n>1 )
+    setSizes(g.readEntry("PanelSizes",QList<int>()));
+
+  active = g.readEntry("ActivePanel", "");
 
   TabView* tv, *activeTV = 0;
   for(tv=_views.first();tv;tv=_views.next()) {
@@ -193,24 +197,24 @@ void MultiView::readViewConfig(KConfig* c,
 
   // activate panel after restoring
   if (!activeTV) activeTV = _views.first();
-  
+
   if (_active == activeTV)
     TraceItemView::activated(_active->activeItem());
   else
     activeTV->setActive(true);
 }
 
-void MultiView::saveViewConfig(KConfig* c, 
-			       QString prefix, QString postfix,
-			       bool withOptions)
+void MultiView::saveViewConfig(KConfig* c,
+                               const QString& prefix, const QString& postfix,
+                               bool withOptions)
 {
-  KConfigGroup g(c, (prefix+postfix).ascii());
-  
+  KConfigGroup g(c, (prefix+postfix).toAscii().constData());
+
   g.writeEntry("Panels", childCount());
   g.writeEntry("Orientation",
 	       (orientation() == Qt::Horizontal) ?
 	       "Horizontal" : "Vertical");
-  
+
   g.writeEntry("PanelSizes", sizes());
   g.writeEntry("ActivePanel", _active ? _active->name() : "none");
 
