@@ -3,7 +3,7 @@
                           ------------------------
     begin                : Tue Jun 26 2001
     Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
-    Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+    Copyright 2001-2009 Otto Bruggeman <bruggie@gmail.com>
     Copyright 2004      Jeff Snyder    <jeff@caffeinated.me.uk>
     Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
  ***************************************************************************/
@@ -119,6 +119,9 @@ KompareConnectWidget::KompareConnectWidget( ViewSettings* settings, QWidget* par
 
 KompareConnectWidget::~KompareConnectWidget()
 {
+	m_settings = 0;
+	m_selectedModel = 0;
+	m_selectedDifference = 0;
 }
 
 void KompareConnectWidget::slotSetSelection( const DiffModel* model, const Difference* diff )
@@ -164,7 +167,7 @@ void KompareConnectWidget::paintEvent( QPaintEvent* /* e */ )
 
 	p->setRenderHint(QPainter::Antialiasing);
 
-	p->fillRect( 0, 0, pixbuf.width(), pixbuf.height(), QColor(Qt::white).dark(110) );
+	p->fillRect( 0, 0, pixbuf.width(), pixbuf.height(), palette().color( QPalette::Window ) );
 
 	KompareSplitter* splitter = static_cast<KompareSplitter*>( parent()->parent() );
 	int count = splitter->count();
@@ -223,14 +226,14 @@ void KompareConnectWidget::paintEvent( QPaintEvent* /* e */ )
 				Q3PointArray topBezier = makeTopBezier( tl, tr );
 				Q3PointArray bottomBezier = makeBottomBezier( bl, br );
 
-				QColor color = m_settings->colorForDifferenceType( diff->type(), selected, diff->applied() ).dark(110);
-				p->setPen( color );
-				p->setBrush( color );
+				QColor bg = m_settings->colorForDifferenceType( diff->type(), selected, diff->applied() );
+				p->setPen( bg );
+				p->setBrush( bg );
 				p->drawPolygon ( makeConnectPoly( topBezier, bottomBezier ) );
 
 				if ( selected )
 				{
-					p->setPen( color.dark(135) );
+					p->setPen( bg.dark(135) );
 					p->drawPolyline( topBezier );
 					p->drawPolyline( bottomBezier );
 				}
