@@ -1,7 +1,7 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2008 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@
 #include "project.h"
 #include "jobs.h"
 
+#include "lokalizemainwindow.h"
+
 #include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -44,6 +46,18 @@
 
 #include <threadweaver/ThreadWeaver.h>
 
+
+
+
+
+
+
+
+
+
+
+
+
 static const char version[] = KAIDER_VERSION;
 static const char description[] =
     I18N_NOOP("Computer-aided translation system.\nDon't translate what had already been translated!");
@@ -59,18 +73,18 @@ int main(int argc, char **argv)
     KCmdLineArgs::init(argc, argv, &about);
 
     KCmdLineOptions options;
-    options.add("merge-source <URL>", ki18n( "Source for the merge mode" ));
-    options.add("project <filename>", ki18n( "Project file. "
-                                 "Opens specified project-file in Project Manager if no translation files specified" ));
+    //options.add("merge-source <URL>", ki18n( "Source for the merge mode" ));
+    options.add("project <filename>", ki18n( "Load specified project."));
     options.add("+[URL]", ki18n( "Document to open" ));
     KCmdLineArgs::addCmdLineOptions(options);
 
     KApplication app;
 
+
     // see if we are starting with session management
     if (app.isSessionRestored())
     {
-        RESTORE(KAider);
+        RESTORE(LokalizeMainWindow);
     }
     else
     {
@@ -82,32 +96,15 @@ int main(int argc, char **argv)
             QString path = args->getOption("project").toUtf8();
             // load needs an absolute path
             // FIXME: I do not know how to handle urls here
-            QFileInfo info( path );
-            Project::instance()->load( info.absoluteFilePath() );
-        }
-        if (args->count() == 0)
-        {
-            if(Project::instance()->isLoaded())
-            {
-                Project::instance()->openProjectWindow();
-                //delete widget;
-            }
-            else
-                (new KAider)->show();
-        }
-        else
-        {
-            KAider *widget = new KAider;
-            widget->fileOpen(args->url(0));
-            if (!args->getOption("merge-source").isEmpty())
-                widget->mergeOpen(KCmdLineArgs::makeURL(args->getOption("merge-source").toUtf8()));
-//             KUrl a(args->arg(0));
-//             QMetaObject::invokeMethod(widget,
-//                                       SLOT(fileOpen(KUrl)),
-//                                       Qt::QueuedConnection,
-//                                       Q_ARG(KUrl,a));
-            widget->show();
+            Project::instance()->load( QFileInfo(path).absoluteFilePath() );
         }
+        LokalizeMainWindow* lmw=new LokalizeMainWindow;
+        kWarning()<<"showing LokalizeMainWindow";
+        lmw->show();
+        kWarning()<<"LokalizeMainWindow shown";
+        int j=args->count();
+        while (--j>=0)
+            lmw->fileOpen(args->url(j));
         args->clear();
     }
 
@@ -119,10 +116,6 @@ int main(int argc, char **argv)
 
         kWarning()<<"Finishing jobs...";
         Project::instance()->save();
-/*        CloseDBJob* closeDBJob=new CloseDBJob(Project::instance()->id(),Project::instance());
-//         connect(closeDBJob,SIGNAL(failed(ThreadWeaver::Job*)),Project::instance(),SLOT(deleteScanJob(ThreadWeaver::Job*)));
-//         connect(closeDBJob,SIGNAL(done(ThreadWeaver::Job*)),Project::instance(),SLOT(deleteScanJob(ThreadWeaver::Job*)));
-        ThreadWeaver::Weaver::instance()->enqueue(closeDBJob);*/
         ThreadWeaver::Weaver::instance()->finish();
     }
     return code;
