@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2007                                               *
+ *   copyright (C) 2004-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -283,7 +283,7 @@ void ClassifierWidget::toggleShowAttSigs()
 int ClassifierWidget::displayedMembers(Uml::Object_Type ot) {
     int count = 0;
     UMLClassifierListItemList list = getClassifier()->getFilteredList(ot);
-    for (UMLClassifierListItem *m = list.first(); m; m = list.next()) {
+    foreach (UMLClassifierListItem *m , list ) {
       if (!(m_bShowPublicOnly && m->getVisibility() != Uml::Visibility::Public))
             count++;
     }
@@ -341,7 +341,7 @@ QSize ClassifierWidget::calculateSize() {
         height += fontHeight * numAtts;
         // calculate width of the attributes
         UMLClassifierListItemList list = getClassifier()->getFilteredList(Uml::ot_Attribute);
-        for (UMLClassifierListItem *a = list.first(); a; a = list.next()) {
+        foreach (UMLClassifierListItem *a , list ) {
             if (m_bShowPublicOnly && a->getVisibility() != Uml::Visibility::Public)
                 continue;
             const int attWidth = fm.size(0,a->toString(m_ShowAttSigs)).width();
@@ -358,7 +358,7 @@ QSize ClassifierWidget::calculateSize() {
         height += numOps * fontHeight;
         // ... width
         UMLOperationList list(getClassifier()->getOpList());
-        for (UMLOperation* op = list.first(); op; op = list.next()) {
+        foreach (UMLOperation* op ,  list) {
                   if (m_bShowPublicOnly && op->getVisibility() != Uml::Visibility::Public)
                 continue;
             const QString displayedOp = op->toString(m_ShowOpSigs);
@@ -392,14 +392,14 @@ QSize ClassifierWidget::calculateSize() {
     return QSize(width, height);
 }
 
-void ClassifierWidget::slotMenuSelection(int sel) {
-    ListPopupMenu::Menu_Type mt = (ListPopupMenu::Menu_Type)sel;
-    switch (mt) {
+void ClassifierWidget::slotMenuSelection(QAction* action) {
+    ListPopupMenu::Menu_Type sel = m_pMenu->getMenuType(action);
+    switch (sel) {
     case ListPopupMenu::mt_Attribute:
     case ListPopupMenu::mt_Operation:
     case ListPopupMenu::mt_Template:
         {
-            Uml::Object_Type ot = ListPopupMenu::convert_MT_OT(mt);
+            Uml::Object_Type ot = ListPopupMenu::convert_MT_OT(sel);
             if (Object_Factory::createChildObject(getClassifier(), ot)) {
                 updateComponentSize();
                 update();
@@ -463,7 +463,7 @@ void ClassifierWidget::slotMenuSelection(int sel) {
         break;
 
     default:
-        UMLWidget::slotMenuSelection(sel);
+        UMLWidget::slotMenuSelection(action);
         break;
     }
 }
@@ -486,7 +486,7 @@ QSize ClassifierWidget::calculateTemplatesBoxSize() {
 
     height = count * fm.lineSpacing() + (MARGIN*2);
 
-    for (UMLTemplate *t = list.first(); t; t = list.next()) {
+    foreach (UMLTemplate *t , list ) {
         int textWidth = fm.size(0, t->toString() ).width();
         if (textWidth > width)
             width = textWidth;
@@ -519,11 +519,11 @@ UMLClassifier *ClassifierWidget::getClassifier() {
 }
 
 void ClassifierWidget::draw(QPainter & p, int offsetX, int offsetY) {
-    UMLWidget::setPen(p);
+    setPenFromSettings(p);
     if ( UMLWidget::getUseFillColour() )
         p.setBrush( UMLWidget::getFillColour() );
     else
-        p.setBrush( m_pView->viewport()->backgroundColor() );
+        p.setBrush( m_pView->viewport()->palette().color(QPalette::Background) );
 
     if (getClassifier()->isInterface() && m_bDrawAsCircle) {
         drawAsCircle(p, offsetX, offsetY);
@@ -552,7 +552,7 @@ void ClassifierWidget::draw(QPainter & p, int offsetX, int offsetY) {
     //If there are any templates then draw them
     UMLTemplateList tlist = getClassifier()->getTemplateList();
     if ( tlist.count() > 0 ) {
-        UMLWidget::setPen(p);
+        setPenFromSettings(p);
         QPen pen = p.pen();
         pen.setStyle(Qt::DotLine);
         p.setPen(pen);
@@ -563,7 +563,7 @@ void ClassifierWidget::draw(QPainter & p, int offsetX, int offsetY) {
         p.setFont(font);
         const int x = offsetX + width() - templatesBoxSize.width() + MARGIN;
         int y = offsetY + MARGIN;
-        for ( UMLTemplate *t = tlist.first(); t; t = tlist.next() ) {
+        foreach ( UMLTemplate *t , tlist ) {
             QString text = t->toString();
             p.drawText(x, y, fm.size(0,text).width(), fontHeight, Qt::AlignVCenter, text);
             y += fontHeight;
@@ -603,7 +603,7 @@ void ClassifierWidget::draw(QPainter & p, int offsetX, int offsetY) {
     p.drawText(textX, m_bodyOffsetY, textWidth, nameHeight, Qt::AlignCenter, name);
     if (!showNameOnly) {
         m_bodyOffsetY += fontHeight;
-        UMLWidget::setPen(p);
+        setPenFromSettings(p);
         p.drawLine(offsetX, m_bodyOffsetY, offsetX + w - 1, m_bodyOffsetY);
         p.setPen(QPen(Qt::black));
     }
@@ -624,7 +624,7 @@ void ClassifierWidget::draw(QPainter & p, int offsetX, int offsetY) {
             m_bodyOffsetY += fontHeight / 2;  // no atts, so just add a bit of space
         else
             m_bodyOffsetY += fontHeight * numAtts;
-        UMLWidget::setPen(p);
+        setPenFromSettings(p);
         p.drawLine(offsetX, m_bodyOffsetY, offsetX + w - 1, m_bodyOffsetY);
         p.setPen(QPen(Qt::black));
     }
@@ -689,7 +689,7 @@ void ClassifierWidget::drawMembers(QPainter & p, Uml::Object_Type ot, Uml::Signa
     QFont f = UMLWidget::getFont();
     f.setBold(false);
     UMLClassifierListItemList list = getClassifier()->getFilteredList(ot);
-    for (UMLClassifierListItem *obj = list.first(); obj; obj = list.next()) {
+    foreach (UMLClassifierListItem *obj , list ) {
           if (m_bShowPublicOnly && obj->getVisibility() != Uml::Visibility::Public)
             continue;
         QString text = obj->toString(sigType);
