@@ -1,24 +1,22 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2007                                               *
+ *   copyright (C) 2003-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "umlroledialog.h"
 
-// qt/kde  includes
-#include <qlayout.h>
+// kde includes
 #include <kdebug.h>
 #include <klocale.h>
 
 // app includes
-#include "../umlrole.h"
+#include "umlrole.h"
 #include "umlroleproperties.h"
 
 UMLRoleDialog::UMLRoleDialog( QWidget * parent, UMLRole * pRole )
@@ -35,36 +33,40 @@ UMLRoleDialog::UMLRoleDialog( QWidget * parent, UMLRole * pRole )
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
 }
 
-UMLRoleDialog::~UMLRoleDialog() {}
+UMLRoleDialog::~UMLRoleDialog()
+{
+}
 
-void UMLRoleDialog::setupDialog() {
-    //          UMLRoleDialogLayout = new QGridLayout( this, 1, 1, 11, 6, "UMLRoleLayout");
+void UMLRoleDialog::setupDialog()
+{
+    // UMLRoleDialogLayout = new QGridLayout( this, 1, 1, 11, 6, "UMLRoleLayout");
     m_pRoleProps = new UMLRoleProperties(this, m_pRole);
     setMainWidget( m_pRoleProps );
 
     resize( QSize(425, 620).expandedTo(minimumSizeHint()) );
 
-    //  topLayout -> addWidget( m_pParmsGB);
-
+    //  topLayout->addWidget( m_pParmsGB);
 }
 
-bool UMLRoleDialog::apply() {
-    if( m_pRoleProps ) {
+bool UMLRoleDialog::apply()
+{
+    if ( m_pRoleProps ) {
         m_pRoleProps->updateObject();
         return true;
     }
     return false;
 }
 
-void UMLRoleDialog::slotApply() {
+void UMLRoleDialog::slotApply()
+{
     apply();
 }
 
-void UMLRoleDialog::slotOk() {
+void UMLRoleDialog::slotOk()
+{
     if ( apply() ) {
         accept();
     }
 }
 
-
 #include "umlroledialog.moc"
